<?php

namespace App\Http\Controllers;

use App\Cargo;
use App\Persona;
use Illuminate\Http\Request;

class PersonaController extends Controller
{
    public function buscar(Request $request){
        if(is_null($request->_cargo)){
            $personas = Persona::buscar($request->_consulta)
                ->with('cargo')
                ->orderBy('id','asc')
                ->paginate(10);
            return view('admin.personas.index')->with('personas', $personas);
        }else{
            $personas = Persona::buscar($request->_consulta)
                ->cargoId($request->_cargo)
                ->with('cargo')
                ->orderBy('id','asc')
                ->paginate(10);
            return view('admin.personas.index')->with('personas', $personas);
        }

    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $personas = Persona::orderBy('id','asc')->paginate(10);
        return view('admin.personas.index')->with('personas',$personas);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $cargo = Cargo::all();
        return view('admin.personas.create')->with('cargo',$cargo);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $persona = new Persona();
        $persona->dni = $request->_dni;
        $persona->nombres = $request->_nombres;
        $persona->apellidos = $request->_apellidos;
        $persona->email = $request->_mail;
        $persona->celular = $request->_celular;
        $persona->cargo_id = $request->_cargo;
        $persona->save();

        return redirect(route('personas_index'));
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Persona  $persona
     * @return \Illuminate\Http\Response
     */
    public function show(Persona $persona)
    {
        return view('admin.personas.show')->with('persona',$persona);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Persona  $persona
     * @return \Illuminate\Http\Response
     */
    public function edit(Persona $persona)
    {
        $cargo = Cargo::all();
        return view('admin.personas.edit')
            ->with('persona',$persona)
            ->with('cargo',$cargo);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Persona  $persona
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Persona $persona)
    {
        $persona->dni = $request->_dni;
        $persona->nombres = $request->_nombres;
        $persona->apellidos = $request->_apellidos;
        $persona->email = $request->_mail;
        $persona->celular = $request->_celular;
        $persona->cargo_id = $request->_cargo;
        $persona->save();

        return redirect(route('personas_show',$persona->id));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Persona  $persona
     * @return \Illuminate\Http\Response
     */
    public function destroy(Persona $persona)
    {
        //
    }
}
